xgboostPred: calculation of stability using a xgboost model.

View source: R/xgboostPred.R

xgboostPredR Documentation

calculation of stability using a xgboost model.

Description

This function will take the dissimilarity matrix and the environmental matrix as input, and calculate the stability of each site using a xgboost model to improve the prediction performance.

Usage

xgboostPred(comdist, envmeta, sitenames = NULL, seed = NULL, params = NULL)

Arguments

comdist

The community dissimilarity matrix

envmeta

The environmental metadata table/matrix

sitenames

The names of the site

seed

The random seed for reproducibility of the xgboost model

params

A list of parameters for the xgboost model. If NULL, default parameters will be used.

Value

a column vector of predicted stability values for each site

Examples

library(vegan)
data(varespec)
data(varechem)
example.comdist <- vegdist(varespec[1:10,])
example.stability_XGB <- xgboostPred(example.comdist, varechem[1:10,])


betaStability documentation built on June 5, 2026, 5:08 p.m.