| rfPred | R Documentation |
This function will take the dissimilarity matrix and the environmental matrix as input, and calculate the stability of each site using a random forest model to improve the prediction performance.
rfPred(comdist, envmeta, sitenames = NULL, seed = NULL)
comdist |
The community dissimilarity matrix |
envmeta |
The environmental metadata table/matrix |
sitenames |
The names of the site |
seed |
The random seed for reproducibility of the random forest model |
a column vector of predicted stability values for each site
library(vegan)
data(varespec)
data(varechem)
example.comdist <- vegdist(varespec[1:10,])
example.stability_RF <- rfPred(example.comdist, varechem[1:10,])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.